import difflib

rule report_mafft:
  input:
    expand('algn/pg.{n}.mafft', n=get_groups_to_align_from_pg_yaml('pgs/protein_groups.yaml'))
  output:
    expand('algn/mafft.{n}.txt', n=get_groups_to_align_from_pg_yaml('pgs/protein_groups.yaml'))
  message:
    "checking pairwise identity of protein groups..."
  run:
    for i in range(len(input)):
        #read seqs
        seqs = []
        with open(input[i], "r") as handle:
            for line in handle:
                line = line.strip()
                if len(line) == 0:
                    continue
                if line[0] == ">":
                    seqs.append([])
                else:
                    seqs[-1].append(line)
        seqs = [''.join(x) for x in seqs]
        l = len(seqs[0])
        seqlens = [len(x.replace("-", "")) for x in seqs]

        #calc relative pairwise identities
        idents = [l-sum(1 for y in zip(x[0], x[1]) if y[0] != y[1]) for x in itertools.combinations(seqs, 2)]
        min_idents = round(min(idents)/l*100,2)
        max_idents = round(max(idents)/l*100,2)

        #write out
        with open(output[i], "w") as handle:
            handle.write("#min_seqlen\tmax_seqlen\tmin_rel_pairw_ident\t#max_rel_pairw_ident\n")
            handle.write(str(min(seqlens)) + "\t" + str(max(seqlens)) + "\t" + str(min_idents) + "\t" + str(max_idents))
