import re

from Bio import SeqIO
from collections import defaultdict


def get_sequences_from_fasta(accs, fasta_fnames):
    """
    Search fasta files for accessions and return dictionary of accessions and sequences
    @param accs: iterable of accession strings
    @param fasta_fnames: filepaths for fasta files
    @return: dictionary, key: accession, value: set of sequences
    """
    if len(accs) == 0:
        return {}
    accs_chars = set()
    for acc in accs:
        accs_chars.update([re.escape(x) for x in list(acc)])
    regex = re.compile("(?<=^>|[\x01|])([" + "".join(accs_chars) + "]+)(?=[| \x01]|$)")
    seqs = defaultdict(set)
    for fname in fasta_fnames:
        with open(fname, 'r') as handle:
            for record in SeqIO.parse(handle, "fasta"):
                for match in accs.intersection(set(regex.findall('>' + record.description))):
                    seqs[match].add(str(record.seq))
    return seqs
